from distutils.core import setup

setup(
        name        ='DTnester',
        version     ='1.1.0',
        py_modules   =['DTnester'],
        author      ='Dreamtecher',
        author_email='349866514@qq.com',
        url         ='http://www.headfirstlabs.com',
        description ='A simple printer of nested lists',
        )
